@@ -70,10 +70,12 @@ whoopsie_identifier_get_mac_address (char** res, GError** error)
         }
     }
 
+    close (sock);
+
     if (!success)
         return;
 
-    *res = malloc (18);
+    *res = g_malloc (18);
     sprintf (*res, "%02x:%02x:%02x:%02x:%02x:%02x",
              (unsigned char) ifr.ifr_hwaddr.sa_data[0],
              (unsigned char) ifr.ifr_hwaddr.sa_data[1],
@@ -96,7 +98,7 @@ whoopsie_identifier_get_system_uuid (char** res, GError** error)
                      "Could not open the product uuid file.");
         return;
     }
-    *res = malloc (37);
+    *res = g_malloc (37);
     if (read (fp, *res, 36) == 36)
         (*res)[36] = '\0';
     else
@@ -168,8 +170,8 @@ whoopsie_identifier_generate (char** res, GError** error)
     return;
 
 out:
-    *res = malloc (HASHLEN + 1);
+    *res = g_malloc (HASHLEN + 1);
     whoopsie_identifier_sha512 (identifier, *res, error);
-    free (identifier);
+    g_free (identifier);
 }
 
